# Example Python Commands using the YellowDog Python SDK

## Overview

This is a set of command line Python scripts for interacting with the YellowDog Platform, providing examples of usage of the [YellowDog Python SDK](https://docs.yellowdog.co/api/python/index.html).

The scripts support:

- **Provisioning** Worker Pools
- **Submitting** Work Requirements
- **Downloading** Results
- **Shutting Down** Worker Pools and **Terminating** Compute Requirements
- **Cancelling** Work Requirements
- **Aborting** running Tasks
- **Deleting** objects in the YellowDog Object Store

Please see the [GitHub repository](https://github.com/yellowdog/python-examples) for more details.
